@@ -33,10 +33,10 @@ def setup_logging(path: str or Path = 'logging.json'):
         logging.config.dictConfig(log_dict)
 
 
-def main_loop(config_path: str = None):
+def main_loop(config_path: str = None, *, delay: int = None):
     setup_logging()
     fh = FindHome(config_path)
-    delay = fh.config.delay
+    delay = delay or fh.config.delay
     while True:
         time.sleep(delay)
         fh.check()
