@@ -10,21 +10,21 @@ from bs4 import BeautifulSoup
 
 logger = logging.getLogger(__name__)
 
-__all__ = ['get_soup', 'PARSER_DICT']
+__all__ = ['get_soup', 'PARSER_DICT', 'parser_decorator']
 
 
-def get_soup(url: str, num_of_attempts: int = 3, delay: float = 0.5) -> BeautifulSoup or None:
+def get_soup(url: str, num_of_attempts: int = 3, delay: float = 1) -> BeautifulSoup or None:
     if num_of_attempts == -1:
         return
     try:
         html = urllib.request.urlopen(url, context=_get_context()).read()
-        logger.info(f'Successfully parsed url.')
+        logger.debug(f'Successfully parsed url.')
         return BeautifulSoup(html, 'html.parser')
     except Exception as err:
         logger.exception(err)
         logger.info(f'Another try in {delay} sec. Number of attempts remained: {num_of_attempts}.')
         time.sleep(delay)
-        return get_soup(url, num_of_attempts - 1)
+        return get_soup(url, num_of_attempts - 1, delay * 2)
 
 
 def _get_context() -> ssl.SSLContext:
@@ -34,14 +34,25 @@ def _get_context() -> ssl.SSLContext:
     return ctx
 
 
-def _parse_wg(debug: bool = False, **kwargs) -> str:
-    url = 'https://www.wg-gesucht.de/wohnungen-in-Tuebingen' \
-          '.127.2.1.0.html?offer_filter=1&sort_column=0&noDeact' \
-          '=1&city_id=127&category=2&rent_type=0&sMin=30&rMax=1500'
+def parser_decorator(url: str):
+    def dec(func):
+        def wrapper(*args, **kwargs):
+            soup = get_soup(url, *args, **kwargs)
+            if soup:
+                return func(soup)
+            else:
+                logger.error(f'Parser returned NoneType object.')
+                return
 
-    soup = get_soup(url, **kwargs)
-    if debug:
-        return soup
+        return wrapper
+
+    return dec
+
+
+@parser_decorator('https://www.wg-gesucht.de/wohnungen-in-Tuebingen'
+                  '.127.2.1.0.html?offer_filter=1&sort_column=0&noDeact'
+                  '=1&city_id=127&category=2&rent_type=0&sMin=30&rMax=1500')
+def _parse_wg(soup: BeautifulSoup) -> str:
     return soup.find_all('div', {'class': 'card_body'})[1].find('h3').find('a').text.strip()
 
 
